@@ -4,28 +4,26 @@
 #
 import io
 import numbers
-import warnings
-from pytest import mark, raises
+from pytest import raises
 
 from wand.color import Color
 from wand.compat import string_type
-from wand.exceptions import DelegateError
 from wand.font import Font
 from wand.image import Image
 from wand.version import MAGICK_VERSION_NUMBER
 
 
-def test_alpha_channel_get(fx_asset):
+def test_alpha_channel_get():
     """Checks if image has alpha channel."""
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img:
+    with Image(width=10, height=10, pseudo='gradient:red-transparent') as img:
         assert img.alpha_channel is True
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(width=10, height=10, pseudo='gradient:red-black') as img:
         assert img.alpha_channel is False
 
 
-def test_alpha_channel_set(fx_asset):
+def test_alpha_channel_set():
     """Sets alpha channel to off."""
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img:
+    with Image(width=10, height=10, pseudo='gradient:red-transparent') as img:
         if MAGICK_VERSION_NUMBER < 0x700:
             enable_option = 'on'
             disable_option = False
@@ -47,22 +45,22 @@ def test_artifacts():
         img.artifacts['key'] = 'value'
         assert 'date:create' in img.artifacts
         assert img.artifacts['key'] == 'value'
-        assert img.artifacts['novalue'] is None
-        assert len(img.artifacts) > 0
-        for key, value in img.artifacts.items():
+        assert img.artifacts['not_a_value'] is None
+        _ = len(img.artifacts)
+        for _ in img.artifacts.items():
             pass
         del img.artifacts['key']
 
 
-def test_background_color_get(fx_asset):
+def test_background_color_get():
     """Gets the background color."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert Color('white') == img.background_color
 
 
-def test_background_color_set(fx_asset):
+def test_background_color_set():
     """Sets the background color."""
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+    with Image(filename='rose:') as img:
         with Color('red') as color:
             img.background_color = color
             assert img.background_color == color
@@ -77,69 +75,37 @@ def test_border_color():
         assert img.border_color == green
 
 
-@mark.xfail(MAGICK_VERSION_NUMBER >= 0x700,
-            reason="Channel traits are not implemented in IM7.")
-def test_channel_depths(fx_asset):
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as i:
-        assert dict(i.channel_depths) == {
-            'blue': 8, 'gray': 8, 'true_alpha': 1, 'opacity': 1,
-            'undefined': 1, 'composite_channels': 8, 'index': 1,
-            'rgb_channels': 8, 'alpha': 1, 'yellow': 8, 'sync_channels': 1,
-            'default_channels': 8, 'black': 1, 'cyan': 8,
-            'all_channels': 8, 'green': 8, 'magenta': 8, 'red': 8,
-            'gray_channels': 8, 'rgb': 8
-        }
-    with Image(filename=str(fx_asset.join('google.ico'))) as i:
-        assert dict(i.channel_depths) == {
-            'blue': 8, 'gray': 8, 'true_alpha': 1, 'opacity': 1,
-            'undefined': 1, 'composite_channels': 8, 'index': 1,
-            'rgb_channels': 8, 'alpha': 1, 'yellow': 8, 'sync_channels': 1,
-            'default_channels': 8, 'black': 1, 'cyan': 8, 'all_channels': 8,
-            'green': 8, 'magenta': 8, 'red': 8, 'gray_channels': 8, 'rgb': 8
-        }
+def test_channel_depths():
+    with Image(filename='rose:') as img:
+        channels = dict(img.channel_depths)
+        assert channels["red"] == channels["green"] == channels["blue"]
 
 
-def test_channel_images(fx_asset):
-    with Image(filename=str(fx_asset.join('sasha.jpg'))) as i:
-        i.format = 'png'
-        channels = ('opacity', 'alpha',)
-        # Only include TrueAlphaChannel if IM6, as its deprecated & unused
-        # in IM7.
-        if MAGICK_VERSION_NUMBER < 0x700:
-            channels = channels + ('true_alpha',)
-        for name in channels:
-            expected_path = str(fx_asset.join('channel_images', name + '.png'))
-            with Image(filename=expected_path) as expected:
-                if MAGICK_VERSION_NUMBER >= 0x700:
-                    # With IM7, channels are dynamic & influence signatures.
-                    # We'll need to compare the first channel of the expected
-                    # PNG with the extracted channel.
-                    first_channel = expected.channel_images['red']
-                    assert i.channel_images[name] == first_channel
-                else:
-                    assert i.channel_images[name] == expected
+def test_channel_images():
+    with Image(width=100, height=100, pseudo='plasma:') as img:
+        assert img.channel_images['red'] != img.channel_images['blue']
 
 
-def test_colors(fx_asset):
-    with Image(filename=str(fx_asset.join('trim-color-test.png'))) as img:
-        assert img.colors == 2
+def test_colors():
+    with Image(filename='rose:') as img:
+        assert img.colors == 3019
 
 
-def test_colorspace_get(fx_asset):
+def test_colorspace_get():
     """Gets the image colorspace"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert img.colorspace.endswith('rgb')
 
 
-def test_colorspace_set(fx_asset):
+def test_colorspace_set():
     """Sets the image colorspace"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.colorspace = 'cmyk'
         assert img.colorspace == 'cmyk'
 
 
-def test_compose(fx_asset):
-    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+def test_compose():
+    with Image(filename='rose:') as img:
         assert img.compose == 'over'
         img.compose = 'blend'
         assert img.compose == 'blend'
@@ -150,7 +116,7 @@ def test_compose(fx_asset):
 
 
 def test_compression(fx_asset):
-    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         # Legacy releases/library asserted ``'group4'`` compression type.
         # IM 7 will correctly report ``'jpeg'``, but ``'group4'`` should
         # still be apart of regression acceptance.
@@ -163,45 +129,40 @@ def test_compression(fx_asset):
 
 def test_compression_quality_get(fx_asset):
     """Gets the image compression quality."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         assert img.compression_quality == 80
 
 
 def test_compression_quality_set(fx_asset):
     """Sets the image compression quality."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         img.compression_quality = 50
         assert img.compression_quality == 50
-        strio = io.BytesIO()
-        img.save(file=strio)
-        strio.seek(0)
-        with Image(file=strio) as jpg:
-            assert jpg.compression_quality == 50
         with raises(TypeError):
             img.compression_quality = 'high'
 
 
-def test_delay_set_get(fx_asset):
-    with Image(filename=str(fx_asset.join('nocomments.gif'))) as img:
+def test_delay_set_get():
+    with Image(filename='rose:') as img:
         img.delay = 10
         assert img.delay == 10
 
 
-def test_depth_get(fx_asset):
+def test_depth_get():
     """Gets the image depth"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert img.depth == 8
 
 
-def test_depth_set(fx_asset):
+def test_depth_set():
     """Sets the image depth"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.depth = 16
         assert img.depth == 16
 
 
 def test_dispose(fx_asset):
-    with Image(filename=str(fx_asset.join('nocomments.gif'))) as img:
+    with Image(filename=str(fx_asset.joinpath('nocomments.gif'))) as img:
         assert img.dispose == 'none'
         img.dispose = 'background'
         assert img.dispose == 'background'
@@ -210,7 +171,7 @@ def test_dispose(fx_asset):
 def test_font_set(fx_asset):
     with Image(width=144, height=192, background=Color('#1e50a2')) as img:
         font = Font(
-            path=str(fx_asset.join('League_Gothic.otf')),
+            path=str(fx_asset.joinpath('League_Gothic.otf')),
             color=Color('gold'),
             size=12,
             antialias=False
@@ -223,7 +184,7 @@ def test_font_set(fx_asset):
         assert img.font == font
         assert repr(img.font)
         fontStroke = Font(
-            path=str(fx_asset.join('League_Gothic.otf')),
+            path=str(fx_asset.joinpath('League_Gothic.otf')),
             stroke_color=Color('ORANGE'),
             stroke_width=1.5
         )
@@ -235,7 +196,7 @@ def test_font_set(fx_asset):
         img.stroke_color = 'gold'
         assert img.stroke_color == Color('gold')
         fontColor = Font(
-            path=str(fx_asset.join('League_Gothic.otf')),
+            path=str(fx_asset.joinpath('League_Gothic.otf')),
             color='YELLOW',
             stroke_color='PINK'
         )
@@ -248,15 +209,15 @@ def test_font_set(fx_asset):
 
 def test_format_get(fx_asset):
     """Gets the image format."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         assert img.format == 'JPEG'
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
+    with Image(filename=str(fx_asset.joinpath('croptest.png'))) as img:
         assert img.format == 'PNG'
 
 
-def test_format_set(fx_asset):
+def test_format_set():
     """Sets the image format."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.format = 'png'
         assert img.format == 'PNG'
         strio = io.BytesIO()
@@ -283,8 +244,9 @@ def test_gravity_set():
         assert img.gravity == 'center'
 
 
-def test_histogram(fx_asset):
-    with Image(filename=str(fx_asset.join('trim-color-test.png'))) as a:
+def test_histogram():
+    with Image(width=1, height=2,
+               pseudo='gradient:srgb(0,255,0)-srgb(0,0,255)') as a:
         h = a.histogram
         assert len(h) == 2
         assert frozenset(h) == frozenset([
@@ -292,36 +254,36 @@ def test_histogram(fx_asset):
             Color('srgb(0,0,255')
         ])
         assert dict(h) == {
-            Color('srgb(0,255,0'): 5000,
-            Color('srgb(0,0,255'): 5000,
+            Color('srgb(0,255,0'): 1,
+            Color('srgb(0,0,255'): 1,
         }
         assert Color('white') not in h
         assert Color('srgb(0,255,0)') in h
         assert Color('srgb(0,0,255)') in h
-        assert h[Color('srgb(0,255,0)')] == 5000
-        assert h[Color('srgb(0,0,255)')] == 5000
+        assert h[Color('srgb(0,255,0)')] == 1
+        assert h[Color('srgb(0,0,255)')] == 1
 
 
-def test_interlace_scheme_get(fx_asset):
+def test_interlace_scheme_get():
     with Image(filename='rose:') as img:
         expected = 'no'
         assert img.interlace_scheme == expected
 
 
-def test_interlace_scheme_set(fx_asset):
+def test_interlace_scheme_set():
     with Image(filename='rose:') as img:
         expected = 'plane'
         img.interlace_scheme = expected
         assert img.interlace_scheme == expected
 
 
-def test_interpolate_method_get(fx_asset):
+def test_interpolate_method_get():
     with Image(filename='rose:') as img:
         expected = 'undefined'
         assert img.interpolate_method == expected
 
 
-def test_interpolate_method_set(fx_asset):
+def test_interpolate_method_set():
     with Image(filename='rose:') as img:
         expected = 'spline'
         img.interpolate_method = expected
@@ -342,14 +304,14 @@ def test_length_of_bytes():
         assert img.length_of_bytes == 0
 
 
-def test_loop(fx_asset):
-    with Image(filename=str(fx_asset.join('nocomments.gif'))) as img:
+def test_loop():
+    with Image(filename='rose:') as img:
         assert img.loop == 0
         img.loop = 1
         assert img.loop == 1
 
 
-def test_matte_color(fx_asset):
+def test_matte_color():
     with Image(filename='rose:') as img:
         with Color('navy') as color:
             img.matte_color = color
@@ -369,8 +331,8 @@ def test_mean():
 
 def test_metadata(fx_asset):
     """Test metadata api"""
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
-        assert 52 <= len(img.metadata) <= 55
+    with Image(filename=str(fx_asset.joinpath('beach.jpg'))) as img:
+        assert len(img.metadata) > 0
         for key in img.metadata:
             assert isinstance(key, string_type)
         assert 'exif:ApertureValue' in img.metadata
@@ -379,88 +341,70 @@ def test_metadata(fx_asset):
         assert img.metadata.get('exif:UnknownValue', "IDK") == "IDK"
 
 
-def test_mimetype(fx_asset):
+def test_mimetype():
     """Gets mimetypes of the image."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
-        assert img.mimetype in ('image/jpeg', 'image/x-jpeg')
-    with Image(filename=str(fx_asset.join('croptest.png'))) as img:
-        assert img.mimetype in ('image/png', 'image/x-png')
+    with Image(filename='rose:') as img:
+        assert img.mimetype in (
+            'image/x-portable-anymap',
+            'image/x-portable-pixmap',
+            'image/x-portable'
+        )
 
 
 def test_minima_maxima():
     with Image(filename='rose:') as img:
-        minq = img.minima
-        maxq = img.maxima
-        assert minq < maxq
+        min_q = img.minima
+        max_q = img.maxima
+        assert min_q < max_q
 
 
 def test_orientation_get(fx_asset):
-    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         assert img.orientation == 'undefined'
 
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('beach.jpg'))) as img:
         assert img.orientation == 'top_left'
 
 
 def test_orientation_set(fx_asset):
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('beach.jpg'))) as img:
         img.orientation = 'bottom_right'
         assert img.orientation == 'bottom_right'
 
 
-def test_page_basic(fx_asset):
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img1:
-        assert img1.page == (640, 480, 0, 0)
-        assert img1.page_width == 640
-        assert img1.page_height == 480
+def test_page_basic():
+    with Image(filename='rose:') as img1:
+        assert img1.page == (70, 46, 0, 0)
+        assert img1.page_width == 70
+        assert img1.page_height == 46
         assert img1.page_x == 0
         assert img1.page_y == 0
         with raises(TypeError):
             img1.page = 640
 
 
-def test_page_offset(fx_asset):
-    with Image(filename=str(fx_asset.join('watermark-offset.png'))) as img1:
-        assert img1.page == (640, 480, 12, 13)
-        assert img1.page_width == 640
-        assert img1.page_height == 480
-        assert img1.page_x == 12
-        assert img1.page_y == 13
+def test_page_setter():
+    with Image(filename='rose:') as img:
+        img.page = (70, 46, 10, 10)
+        assert img.page == (70, 46, 10, 10)
+        img.page = (70, 46, -10, -10)
+        assert img.page == (70, 46, -10, -10)
+        img.page_width = 60
+        img.page_height = 40
+        img.page_x = 0
+        img.page_y = 0
+        assert img.page == (60, 40, 0, 0)
 
 
-def test_page_setter(fx_asset):
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img1:
-        assert img1.page == (640, 480, 0, 0)
-        img1.page = (640, 480, 0, 0)
-        assert img1.page == (640, 480, 0, 0)
-        img1.page = (640, 480, 12, 13)
-        assert img1.page == (640, 480, 12, 13)
-        img1.page = (640, 480, -12, 13)
-        assert img1.page == (640, 480, -12, 13)
-        img1.page = (640, 480, 12, -13)
-        assert img1.page == (640, 480, 12, -13)
-        img1.page = (6400, 4800, 2, 3)
-        assert img1.page == (6400, 4800, 2, 3)
+def test_page_setter_papersize():
+    with Image(filename='rose:') as img:
+        img.page = 'a4'
+        assert img.page == (595, 842, 0, 0)
+        img.page = 'badvalue'
+        assert img.page == (0, 0, 0, 0)
 
 
-def test_page_setter_items(fx_asset):
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img1:
-        assert img1.page == (640, 480, 0, 0)
-        img1.page_width = 6400
-        assert img1.page == (6400, 480, 0, 0)
-        img1.page_height = 4800
-        assert img1.page == (6400, 4800, 0, 0)
-        img1.page_x = 12
-        assert img1.page == (6400, 4800, 12, 0)
-        img1.page_y = 13
-        assert img1.page == (6400, 4800, 12, 13)
-        img1.page_x = -12
-        assert img1.page == (6400, 4800, -12, 13)
-        img1.page_y = -13
-        assert img1.page == (6400, 4800, -12, -13)
-
-
-def test_primary_points(fx_asset):
+def test_primary_points():
     with Image(filename='rose:') as img:
         blue = [d/2 for d in img.blue_primary]
         img.blue_primary = blue
@@ -485,7 +429,7 @@ def test_primary_points(fx_asset):
 
 
 def test_profiles(fx_asset):
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('beach.jpg'))) as img:
         assert len(img.profiles) == 1
         assert 'exif' in [d for d in img.profiles]
         exif_data = img.profiles['exif']
@@ -505,7 +449,7 @@ def test_profiles(fx_asset):
 
 
 def test_rendering_intent(fx_asset):
-    with Image(filename=str(fx_asset.join('trimtest.png'))) as img:
+    with Image(filename=str(fx_asset.joinpath('trimtest.png'))) as img:
         assert img.rendering_intent == 'perceptual'
         img.rendering_intent = 'relative'
         assert img.rendering_intent == 'relative'
@@ -513,44 +457,34 @@ def test_rendering_intent(fx_asset):
 
 def test_resolution_get(fx_asset):
     """Gets image resolution."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         assert img.resolution == (72, 72)
 
 
 def test_resolution_set_01(fx_asset):
     """Sets image resolution."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         img.resolution = (100, 100)
         assert img.resolution == (100, 100)
 
 
 def test_resolution_set_02(fx_asset):
     """Sets image resolution with integer as parameter."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename=str(fx_asset.joinpath('mona-lisa.jpg'))) as img:
         img.resolution = 100
         assert img.resolution == (100, 100)
 
 
-@mark.pdf
-def test_resolution_set_03(fx_asset):
+def test_resolution_set_03():
     """Sets image resolution on constructor"""
-    try:
-        with Image(filename=str(fx_asset.join('sample.pdf')),
-                   resolution=(100, 100)) as img:
-            assert img.resolution == (100, 100)
-    except DelegateError:
-        warnings.warn('PDF delegate could not be found.')
+    with Image(filename='rose:', resolution=(100, 100)) as img:
+        assert img.resolution == (100, 100)
 
 
-@mark.pdf
-def test_resolution_set_04(fx_asset):
+def test_resolution_set_04():
     """Sets image resolution on constructor with integer as parameter."""
-    try:
-        with Image(filename=str(fx_asset.join('sample.pdf')),
-                   resolution=100) as img:
-            assert img.resolution == (100, 100)
-    except DelegateError:
-        warnings.warn('PDF delegate could not be found.')
+    with Image(filename='rose:', resolution=100) as img:
+        assert img.resolution == (100, 100)
 
 
 def test_sampling_factors():
@@ -567,25 +501,19 @@ def test_scene():
         assert img.scene == 4
 
 
-def test_signature(fx_asset):
+def test_signature():
     """Gets the image signature."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
-        with fx_asset.join('mona-lisa.jpg').open('rb') as f:
-            with Image(file=f) as same:
-                assert img.signature == same.signature
-        with img.convert('png') as same:
-            assert img.signature == same.signature
-        with Image(filename=str(fx_asset.join('beach.jpg'))) as diff:
-            assert img.signature != diff.signature
+    with Image(filename='rose:') as img:
+        assert img.signature
 
 
-def test_size(fx_asset):
+def test_size():
     """Gets the image size."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
-        assert img.size == (402, 599)
-        assert img.width == 402
-        assert img.height == 599
-        assert len(img) == 599
+    with Image(filename='rose:') as img:
+        assert img.size == (70, 46)
+        assert img.width == 70
+        assert img.height == 46
+        assert len(img) == 46
 
 
 def test_skewness():
@@ -611,9 +539,9 @@ def test_stroke_color_user_error():
             img.stroke_color = 0xDEADBEEF
 
 
-def test_type_get(fx_asset):
+def test_type_get():
     """Gets the image type."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert img.type == "truecolor"
         img.alpha_channel = True
         if MAGICK_VERSION_NUMBER < 0x700:
@@ -623,44 +551,44 @@ def test_type_get(fx_asset):
         assert img.type == expected
 
 
-def test_type_set(fx_asset):
+def test_type_set():
     """Sets the image type."""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.type = "grayscale"
         assert img.type == "grayscale"
 
 
-def test_ticks_per_second(fx_asset):
-    with Image(filename=str(fx_asset.join('nocomments.gif'))) as img:
+def test_ticks_per_second():
+    with Image(filename='rose:') as img:
         assert img.ticks_per_second == 100
         img.ticks_per_second = 10
         assert img.ticks_per_second == 10
 
 
-def test_units_get(fx_asset):
+def test_units_get():
     """Gets the image resolution units."""
-    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+    with Image(filename='rose:', units='pixelsperinch') as img:
         assert img.units == "pixelsperinch"
-    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert img.units == "undefined"
 
 
-def test_units_set(fx_asset):
+def test_units_set():
     """Sets the image resolution units."""
-    with Image(filename=str(fx_asset.join('watermark.png'))) as img:
+    with Image(filename='rose:') as img:
         img.units = "pixelspercentimeter"
         assert img.units == "pixelspercentimeter"
 
 
-def test_virtual_pixel_get(fx_asset):
+def test_virtual_pixel_get():
     """Gets image virtual pixel"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         assert img.virtual_pixel == "undefined"
 
 
-def test_virtual_pixel_set(fx_asset):
+def test_virtual_pixel_set():
     """Sets image virtual pixel"""
-    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+    with Image(filename='rose:') as img:
         img.virtual_pixel = "tile"
         assert img.virtual_pixel == "tile"
         with raises(ValueError):
